# Help to translate videomass to other languages
-----------------

The localization guidelines can be found on the 
[Translate Videomass Offline](https://jeanslack.github.io/Videomass/Pages/Localization_Guidelines.html) 
web page.   

To update an already translated language, please visit 
[Updates an existing translation](https://jeanslack.github.io/Videomass/Pages/Localization_Guidelines.html#updates-an-existing-translation) 
page.   

To start with a new translation language, please visit 
[Start with a new translation](https://jeanslack.github.io/Videomass/Pages/Localization_Guidelines.html#start-with-a-new-translation ) 
page.   


